-- Smart Tracker, by Thortok2000
-- First addon I ever made from scratch, so be nice!

function ST_OnLoad(self)

	self:RegisterEvent("PLAYER_LOGIN");						-- Register for the event that happens once per session on login or UI reload.
	self:RegisterEvent("UPDATE_INVENTORY_ALERTS");			-- Register for the event that triggers when items yellow/red status changes.
	self:RegisterEvent("UPDATE_PENDING_MAIL");				-- Register for the event that triggers when you might have unread mail in the inbox.
	self:RegisterEvent("MAIL_SHOW");						-- Register for the event that triggers when you open a mailbox.
	--self:RegisterEvent("QUEST_POI_UPDATE");
	--self:RegisterEvent("QUEST_LOG_UPDATE");
	--self:RegisterEvent("QUEST_ITEM_UPDATE");
	--self:RegisterEvent("QUEST_WATCH_UPDATE");
	--self:RegisterEvent("UNIT_QUEST_LOG_CHANGED");
	
	-- Forms of tracking not currently supported but might be supported in the future:
	-- Auctioneer, Banker, Battlemaster, Food & Drink, Innkeeper, Profession Trainer, Reagents, Stable Master, Flight Master
	
end

function ST_OnEvent(self, event, arg1)
	
	local ST_RepairID = nil;
	local ST_MailboxID = nil;
	
	for index = 1, GetNumTrackingTypes() do					--	Loop through all the tracking types available
		local name = GetTrackingInfo(index);				--	Look at the name of each for comparison
		if name == MINIMAP_TRACKING_REPAIR then				--  Repair Vendors
			ST_RepairID = index;
		elseif name == MINIMAP_TRACKING_MAILBOX then		--  Mailboxes
			ST_MailboxID = index;
		elseif index == GetNumTrackingTypes() then							-- End of the loop, run a debug check to make sure ID's have been found.  Should never happen, but you never know.
			if ST_RepairID == nil then										
				print("SmartTracker Error: No Repair Tracking Found!");
			end
			if ST_MailboxID == nil then
				print("SmartTracker Error: No Mailbox Tracking Found!");
			end
		end
	end

	if( event == "UPDATE_INVENTORY_ALERTS" or event == "PLAYER_LOGIN" ) then			-- The event when items yellow/red status changes.
		for index = 1, 20 do		-- There's less than 20 slots in the inventory so this should work regardless of if the slots change names or positions or amounts
			if GetInventoryAlertStatus(index) > 0 then		--  1 means yellow, 2 means red, 0 means not yellow or red so any value above 0 on any slot means the icon is showing.
				SetTracking(ST_RepairID, true);		--	Turn on repair tracking
				return;
			elseif index == 20 then							--  We've checked all the way through to slot 20 and nothing is yellow or red
				SetTracking(ST_RepairID, false);		--  Turn off repair tracking
			end
		end
	elseif( event == "UPDATE_PENDING_MAIL" or event == "PLAYER_LOGIN" ) then				-- The event when you might have new mail.
		if HasNewMail() == 1 then							-- A double check condition to make sure the mail is actually new.
			SetTracking(ST_MailboxID, true);					-- Turn on mailbox tracking
		else
			SetTracking(ST_MailboxID, false);					-- We don't have new mail, so if mailbox tracking is currently on for some reason, turn it off.
		end
	elseif( event == "MAIL_SHOW" ) then							-- The event for opening a mailbox.
		SetTracking(ST_MailboxID, false);					-- Turn off mailbox tracking.
	end
end

function ST_AutoPOIPicker()					-- Track the first quest on the watch list.
	if GetQuestIndexForWatch(1) then
		WORLDMAP_SETTINGS.selectedQuestId = select(9, GetQuestLogTitle(GetQuestIndexForWatch(1)));
		QuestPOI_SelectButtonByQuestId("WatchFrameLines", select(9, GetQuestLogTitle(GetQuestIndexForWatch(1))), true);			-- The current format which just assumes the first quest in line is something that can be pointed at.
		SetSuperTrackedQuestID(select(9, GetQuestLogTitle(GetQuestIndexForWatch(1))));
	end
end

WatchFrame:HookScript("OnUpdate", ST_AutoPOIPicker)				-- Whenever the order of the list in the objective/watch frame changes for any reason, track the first one on the list.